
//=================================================================
//
//  Simple RF powermeter
//
//  (c) Dietmar Krause, DL2SBA
//
//  License see https://creativecommons.org/licenses/by/4.0/
//
//  Using the following libraries
//
//      https://www.arduino.cc/en/Reference/EEPROM
//      http://playground.arduino.cc/Main/MsTimer2
//      https://github.com/dl2sba/AD7887
//      https://github.com/dl2sba/AD8318
//      https://github.com/dl2sba/PeakHold
//      https://github.com/DanNixon/NeoNextion
//
#include <EEPROM.h>
#include <MsTimer2.h>

#include <Nextion.h>
#include <NextionPage.h>
#include <NextionText.h>

#include <AD7887.h>

#include <PeakHold.h>


#include "data.h"
#include "config.h"

extern void initSetupMode( void );
extern void initRunMode( void );
extern void initRawMode( void );
extern void switchToRunMode(NextionEventType type, INextionTouchable *widget);
extern void handleRunMode( void );
extern void handleRawMode( void );
extern void handleSetupMode( void );

uint32_t NumberOfWidgets EEMEM = 0xAABBCCDD;

//=================================================================
//
//  The welcome page
NextionPage         pgWelcome(nex, 1, 0, "page1");
NextionText         t0Welcome(nex, 1, 1, "t0");


//=================================================================
//
//  The adc instance
//
#define SPICLOCK    9  // Clock         -> connect to PIN 1 of SV1AFN module
#define SELPIN     10  // Selection Pin -> connect to PIN 2 of SV1AFN module
#define DATAIN     11  // DATA from ADC -> connect to PIN 3 of SV1AFN module
#define DATAOUT    12  // DATA to ADC   -> connect to PIN 5 of SV1AFN module

AD7887 powerSensor = AD7887(SELPIN, DATAOUT, DATAIN, SPICLOCK);

//=================================================================
//
//  interrupt handler
//
void interruptHandler ( void ) {
  //  toggle visual indicator
  digitalWrite(PORT_ISR, HIGH);

  static uint8_t i;
  static uint32_t sum;

  //  get sensor reading
  isrActValue = powerSensor.readADC();

  //  put into averaging buffer
  dataBuffer[dataBufferIndex] = isrActValue;
  dataBufferIndex = (dataBufferIndex + 1 ) % currentBufferSize;
  sum = 0;
  for ( i = 0; i < currentBufferSize; ++i ) {
    sum += dataBuffer[i];
  }
  isrAvgValue = sum / currentBufferSize;

  minHold.consume(isrActValue);
  maxHold.consume(isrActValue);

  //  toggle visual indicator
  digitalWrite(PORT_ISR, LOW);
}


//=================================================================
//
//  setup the device
//
void setup() {
  // this crappy uno-clone has a reset problem
  delay(1000);

  // flashes on each measurement
  pinMode(PORT_RUN, OUTPUT);
  pinMode(PORT_ISR, OUTPUT);

  //
  readConfig();

  //init the GUI
  NEXTION_PORT.begin(9600);
  nex.init();

  pgWelcome.show();
  t0Welcome.setText(VERSION_TAG);
  delay(2000);

  initSetupMode();
  initRunMode();
  initRawMode();

  // set measurement intervall
  MsTimer2::set(1000 / MEASUREMENT_FREQUENCY, interruptHandler);
  MsTimer2::start();

  // start run mode
  switchToRunMode(0, 0);
}



//=================================================================
//
//  main loop
//
void loop(void)
{
  // provide the GUI some time
  nex.poll();

  //   which mode?
  if ( mode == MODE_RUN ) {
    handleRunMode();
  } else if ( mode == MODE_SETUP ) {
    handleSetupMode();
  } else if ( mode == MODE_RAW ) {
    handleRawMode();
  }
}


