//=================================================================
//
//  Simple RF powermeter
//
//  (c) Dietmar Krause, DL2SBA
//
//  License see https://creativecommons.org/licenses/by/4.0/
//
#include <MsTimer2.h>

#include <Nextion.h>
#include <NextionPage.h>
#include <NextionButton.h>
#include <NextionText.h>

#include <PeakHold.h>

#include "data.h"
#include "config.h"

static NextionPage         pgRaw(nex,   3, 0,  "page3");
static NextionButton       btRaw(nex,   3, 1,  "b0");
static NextionText         txtRaw(nex,  3, 4,  "t2");

extern void switchToRunMode(NextionEventType type, INextionTouchable * widget);


//=================================================================
//
//  do the stuff for peak measurement
//
void handleRawMode( void ) {
  static uint16_t localActValue;

  // stop background task
  noInterrupts();

  //    copy isr values to local values
  localActValue = isrActValue;

  //    reenable background task
  interrupts();

  itoa(localActValue, dtostrfBuffer, 10); txtRaw.setText(dtostrfBuffer);
}

//=================================================================
//
//  switch instrument into raw mode
//
void switchToRawMode(NextionEventType type, INextionTouchable * widget) {
  // show page
  pgRaw.show();

  // switch to mode
  mode = MODE_RAW;
}



//=================================================================
//
//  save config and switch instrument into measurement mode
//
static void cbSwitchToRunMode(NextionEventType type, INextionTouchable * widget) {
  // write config data to eeprom
  writeConfig();

  // start timer again
  MsTimer2::start();

  // change mode
  switchToRunMode(type, widget);
}



//=================================================================
//
//
void initRawMode( void ) {
  //
  btRaw.attachCallback(&cbSwitchToRunMode);
}
