//=================================================================
//
//  Simple RF powermeter
//
//  (c) Dietmar Krause, DL2SBA
//
//  License see https://creativecommons.org/licenses/by/4.0/
//

#include <EEPROM.h>
#include <Nextion.h>
#include <PeakHold.h>

#include "data.h"
#include "config.h"

//=================================================================
//
//  write the current config to EEPROM including magic
void writeConfig(void) {
  EEPROM.put(EE_ADR_MAGIC,      EE_MAGIC );
  EEPROM.put(EE_ADR_AVERAGE,    currentBufferSize);
  EEPROM.put(EE_ADR_PEAKDELAY,  peakHoldCurrent);
  EEPROM.put(EE_ADR_PEAKDECAY,  peakDecayCurrent);
  EEPROM.put(EE_ADR_BACKLIGHT,  backlight);
  EEPROM.put(EE_ADR_POWEROFFSET,powerOffset_Index);
  EEPROM.put(EE_ADR_CALFREQ,    calFreqIdx);
}

//=================================================================
//
//  Check if magic is correct set in EEPROM?
//
//  if so, load the config variables from the EEPROM
//  if not, load config variables with their defaults and store to EEPROM
//
void readConfig (void) {
  uint16_t magic;
  EEPROM.get(EE_ADR_MAGIC, magic);

  if ( magic == EE_MAGIC ) {
    EEPROM.get(EE_ADR_AVERAGE,     currentBufferSize);
    EEPROM.get(EE_ADR_PEAKDELAY,   peakHoldCurrent);
    EEPROM.get(EE_ADR_PEAKDECAY,   peakDecayCurrent);
    EEPROM.get(EE_ADR_BACKLIGHT,   backlight);
    EEPROM.get(EE_ADR_POWEROFFSET, powerOffset_Index);
    EEPROM.get(EE_ADR_CALFREQ,     calFreqIdx);
  } else {
    currentBufferSize   = DATA_BUFFER_SIZE_INIT;
    peakHoldCurrent     = T_PEAKHOLD_INIT;
    peakDecayCurrent    = T_PEAKDECAY_INIT;
    backlight           = BACKLIGHT_INIT;
    powerOffset_Index   = POWER_OFFSET_INIT;
    calFreqIdx          = CALFREQ_INIT;
    writeConfig();
  }
}

